Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewMockLaneState ¶
NewMockLaneState constructs a state for a payment channel lane with the set fixed values that satisfies the paych.LaneState interface. Useful for populating lanes when calling NewMockPayChState
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.